@@ -2,7 +2,7 @@
     Manage custom options
                              -------------------
     begin                : Fr 29 Apr 2011
-    copyright            : (C) 2011-2017 by Alexander Reinholdt
+    copyright            : (C) 2011-2019 by Alexander Reinholdt
     email                : alexander.reinholdt@kdemail.net
  ***************************************************************************/
 
@@ -27,13 +27,11 @@
 #define SMB4KCUSTOMOPTIONSMANAGER_H
 
 // application specific includes
-#include "smb4kcustomoptions.h"
 #include "smb4kglobal.h"
 
 // Qt includes
 #include <QObject>
 #include <QScopedPointer>
-#include <QWidget>
 
 // forward declarations
 class Smb4KCustomOptionsManagerPrivate;
@@ -71,7 +69,7 @@ class Q_DECL_EXPORT Smb4KCustomOptionsManager : public QObject
      * @returns a static pointer to this class
      */
     static Smb4KCustomOptionsManager *self();
-    
+
     /**
      * Add the share to the list of shares that are to be remounted
      * either only on next program start or always Smb4K is restarted.
@@ -172,7 +170,7 @@ class Q_DECL_EXPORT Smb4KCustomOptionsManager : public QObject
      * 
      * @param parent              The parent widget
      */
-    void openCustomOptionsDialog(const NetworkItemPtr &item, QWidget *parent = 0);
+    void openCustomOptionsDialog(const NetworkItemPtr &item);
     
     /**
      * This function adds custom options for a single network item to the list
@@ -194,22 +192,13 @@ class Q_DECL_EXPORT Smb4KCustomOptionsManager : public QObject
      */
     void removeCustomOptions(const OptionsPtr &options);
     
-    /**
-     * This functions checks if the options object indeed carries custom
-     * options. It does not test for the value of remount(), so you need 
-     * do check it, too.
-     * @param options       The custom options object
-     * @returns TRUE if there are custom options defined and FALSE otherwise.
-     */
-    bool hasCustomOptions(const OptionsPtr &options);
-    
     /**
      * This function returns a list of custom option objects that have 
      * Wake-On-LAN features defined.
      * 
     * @returns a list of custom options objects with WOL features defined.
     */
-    QList<OptionsPtr> wolEntries() const;
+    QList<OptionsPtr> wakeOnLanEntries() const;
     
     /**
      * Reload custom options from the file.              
